#!/bin/bash
# /usr/local/bin/change_display.sh
# composant du package primtux-tbi
# Homepage: https://debian-facile.org/utilisateurs:lebardix:tutos:primtux-tbi

# fichier de traitement des evenements acpid pour la gestion des écrans
# cas du thinkpad X220 avec le bouton thinkvantage
ACPI_CMD_FILE=$HOME/.config/acpi_screen.sh
ACPI_CMD_LOG=$HOME/.cache/acpi_thinkvantage.log
ACPI_CMD_CUR=$HOME/.cache/acpi_thinkvantage.cur

# configuration
if [ -f /etc/lightdm/screens/definition-ecrans.conf]
then    
        source /etc/lightdm/screens/definition-ecrans.conf
else
        source /etc/lightdm/screens/definition-ecrans.default
fi


# pas de modification après cette ligne
# ATTENTION lire cependant la fonction get_mode pour les résolutions d'affichage
#----------------------------------------------------------------------------------------------
readonly -a screen_mode=(\
	"écran portable seul" \
	"écran secondaire seul haute-résolution" \
	"ecran portable et secondaire étendus" \
	"écrans portable et TBI clonés" \
	"écrans portable et TBI étendus" \
	"écrans secondaire et TBI clonés" \
	"écrans secondaire et TBI étendus" ) 

function get_screen ()
{
	# identification des écrans connectés
	for screen in $(xrandr --query | grep connected | grep -v disconnected |cut -d\  -f1)
	do
		echo -n +${dev_by_role["$screen"]}
	done
}

function get_mode ()
{
# suivant les écrans disponibles, proposer le mode d'affichage de chacun des roles possibles
# ce script n'est pas complet dans le sens ou vous devez préciser la résolution, 
# une version ultérieure pourrait proposer la selection de la résolution dans le configurateur
# ou meme de de traiter des résolutions automatiques

	A=$(get_screen)
	case $A in
		+portable )
			echo ${A}_portable-U
		       	echo ${screen_mode[0]}
			echo "\"(xrandr -d :0.0 --size 1366x768 --output ${role_by_dev["portable"]} --mode 1366x768 --primary;)\""
			;;
		+portable+secondaire )
			echo ${A}_portable-U
			echo ${screen_mode[0]}
			echo "\"(xrandr -d :0.0 --size 1440x900 --output ${role_by_dev["portable"]} --mode 1366x768 --primary --output ${role_by_dev["secondaire"]} --off;)\""
			echo ${A}_secondaire-U
			echo ${screen_mode[1]}
			echo "\"(xrandr -d :0.0 --size 1440x900 --output ${role_by_dev["secondaire"]} --mode 1440x900 --primary --output ${role_by_dev["portable"]} --off;)\""
			echo ${A}_portable*secondaire-E
			echo ${screen_mode[2]}
			echo "\"(xrandr -d :0.0 --size 2880x900 --output ${role_by_dev["portable"]} --mode 1366x768 --primary --output ${role_by_dev["secondaire"]} --mode 1440x900 --right-of ${role_by_dev["portable"]};)\" iacb  "
			;;
		+portable+secondaire+TBI | +portable+TBI+secondaire )
			echo ${A}_portable-U
			echo ${screen_mode[0]}
			echo "\"(xrandr -d :0.0 --size 1440x900 --output ${role_by_dev["portable"]} --mode 1366x768 --primary --output ${role_by_dev["secondaire"]} --off;xrandr -d :0.0 --output ${role_by_dev["TBI"]} --off;)\""
			echo ${A}_secondaire-U
			echo ${screen_mode[1]}
			echo "\"(xrandr -d :0.0 --size 1440x900 --output ${role_by_dev["secondaire"]} --mode 1440x900 --primary --output ${role_by_dev["portable"]} --off;xrandr -d :0.0 --output ${role_by_dev["TBI"]} --off;)\""
			echo ${A}_secondaire*TBI-C
			echo ${screen_mode[5]}
			echo "\"(xrandr -d :0.0 --size 1440x900 --output ${role_by_dev["secondaire"]} --mode 1440x900 --primary --output ${role_by_dev["TBI"]} --mode 1440x900 --same-as ${role_by_dev["secondaire"]}; xrandr -d :0.0 --output ${role_by_dev["portable"]} --off;)\""
			echo ${A}_secondaire*TBI-E
			echo ${screen_mode[6]}
			echo "\"(xrandr -d :0.0 --size 2880x900 --output ${role_by_dev["secondaire"]} --mode 1440x900 --primary --output ${role_by_dev["TBI"]} --mode 1440x900 --right-of ${role_by_dev["secondaire"]}; xrandr -d :0.0 --output ${role_by_dev["portable"]} --off;)\""
			;;
		+portable+TBI )
			echo ${A}_portable-U
			echo ${screen_mode[1]}
			echo "\"(xrandr -d :0.0 --size 1440x900 --output ${role_by_dev["portable"]} --mode 1366x768 --primary --output ${role_by_dev["TBI"]} --off;)\""
			echo ${A}_portable*TBI-C
			echo ${screen_mode[3]}
			echo "\"(xrandr -d :0.0 --size 1440x900 --output ${role_by_dev["portable"]} --mode 1366x768 --primary --output ${role_by_dev["TBI"]} --mode 1440x900 --same-as ${role_by_dev["portable"]};)\""
			echo ${A}_portable*TBI-E
			echo ${screen_mode[4]}
			echo "\"(xrandr -d :0.0 --size 2880x900 --output ${role_by_dev["portable"]} --mode 1366x768 --primary --output ${role_by_dev["TBI"]} --mode 1440x900 --right-of ${role_by_dev["portable"]};)\""
			;;
		+secondaire+TBI | +TBI+secondaire )
			echo ${A}_secondaire-U
			echo ${screen_mode[1]}
			echo "\"(xrandr -d :0.0 --size 1440x900 --output ${role_by_dev["secondaire"]} --mode 1440x900 --primary --output ${role_by_dev["TBI"]} --off;)\""
			echo ${A}_secondaire*TBI-C
			echo ${screen_mode[5]}
			echo "\"(xrandr -d :0.0 --size 1440x900 --output ${role_by_dev["secondaire"]} --mode 1366x768 --primary --output ${role_by_dev["TBI"]} --mode 1440x900 --same-as ${role_by_dev["secondaire"]};)\""
			echo ${A}_secondaire*TBI-E
			echo ${screen_mode[6]}
			echo "\"(xrandr -d :0.0 --size 2880x900 --output ${role_by_dev["secondaire"]} --mode 1366x768 --primary --output ${role_by_dev["TBI"]} --mode 1440x900 --right-of ${role_by_dev["secondaire"]};)\""
			;;
	esac
}

function acpi_set_acpidisplay () {

   declare -i n=0
   # ce configurateur	
   # genere le script de traitement des modes d'affichage par l'acpi
   # valide les modes d'affichage suivant les devices disponibles proposés par ce configurateur
   # debut du script de commandei on initialise les logs
   echo "nouvelle config $(date)" >${ACPI_CMD_LOG}
   echo "#/bin/bash" >$ACPI_CMD_FILE
   echo "echo thinkvantage \$(date) >>${ACPI_CMD_LOG}" >>$ACPI_CMD_FILE
   # verification de l'appel, 
   # sans argument la demande provient du bouton thinkvantage
   # le nouvel affichage sera le mode suivant défini par le configurateur
   # avec argument, le mode choisi sera celui du numero donné
   # il peut provenir de l'insertion ou l'extraction du dock (station) ou d'une commande manuelle
   # la mémorisation du mode "fichier .cur" reste inchangé et peut donc etre en discordance avec l'état réel 
   # suite à l'extraction ou  l'insertion du PC dans sa station (utilisation de l'acpi)  
   echo "echo \"args option demandée \$* \" >>${ACPI_CMD_LOG}" >>$ACPI_CMD_FILE
   echo "if [ -z \"\$1\" ]" >>$ACPI_CMD_FILE
   echo "then k=\$(cat $ACPI_CMD_CUR);" >>$ACPI_CMD_FILE 
   echo "else k=\$1;" >>$ACPI_CMD_FILE
   echo "fi" >>$ACPI_CMD_FILE

   echo "case \$k in" >>$ACPI_CMD_FILE

   #on recupere les parametres issus de l'interface du configurateur
   # attention les commandes à lancer défini dans les menus du configurateur doivent etre encadrer avec "( lescommandesici; )"
   ACPI=$(get_mode)
   # supprimer les caractères après le dernier " au cas ou
   # et verifier que la chaine se termine bien par )" 
   ACPI=${ACPI%\"*}\"
   FMT=${ACPI%%*)\"}
   if [ ${#FMT} -eq 0 ] 
   then
   while [ -n "$ACPI" ]
   do
	# extraction des commandes
	CMD=${ACPI#*\"(}
	ACPI=$CMD
	CMD=${CMD%%)\"*}
	echo "-----------$CMD"
	ACPI=${ACPI#$CMD)\"}
	# introduire dans le script de controle acpi
	echo "  $n)" >>$ACPI_CMD_FILE
	echo "    $CMD" >>$ACPI_CMD_FILE
	if [ $n -eq 0 ] ; then CMD_default=$CMD; fi 
	n=$(( n + 1 ))
	echo "    echo $n >$ACPI_CMD_CUR" >>$ACPI_CMD_FILE
	echo "    ;;" >>$ACPI_CMD_FILE
   done
   fi
   # les autres choix sont traités comme l'option 0 choix par défaut (ecran principal/portable)
   echo "  *)" >>$ACPI_CMD_FILE
   echo "    $CMD_default" >>$ACPI_CMD_FILE
   echo "    echo '1' >$ACPI_CMD_CUR" >>$ACPI_CMD_FILE
   echo "    ;;" >>$ACPI_CMD_FILE
   echo "esac" >>$ACPI_CMD_FILE
   echo "newscript_conf $(date)" >${ACPI_CMD_LOG}
   echo "0" >${ACPI_CMD_CUR}
   # droit X au script
   chmod +x $ACPI_CMD_FILE
}

function set_display () {
   # affecte le choix à l'affichage
   CHOIX=${CHOIX%\"*}\"
   CMD=${CHOIX##*|}
   CMD=${CMD%\"*}\"
   CMD=${CMD#*\"(}
   CMD=${CMD%%)\"*}
   eval $CMD
}

CHOIX=$(  echo "$(get_mode)" | zenity  --list --title "Changer affichage écrans" --column "Choix" --column "Affichage" --column "commande" --hide-header --hide-column=1 --print-column=ALL )

set_display
acpi_set_acpidisplay

# end
